/*
 *  Status monitor for Canon CAPT Printer.
 *  Copyright (C) 2004-2009 CANON INC.
 *  All Rights Reserved.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "support.h"
#include "uimain.h"
#include "widgets.h"
#include "interface.h"
#include "ccinfodlg.h"
#include "data_process.h"

enum{
	CRT_STR_AVAILABLE,
	CRT_STR_SOON,
	CRT_STR_CHECK,
	CRT_STR_REPLACE,
	CRT_STR_INSERT,
	CRT_STR_UNKNOWN,
};

static char *CartridgeStr[] = {
	N_("Available"),
	N_("Replacement Needed Soon"),
	N_("Check Cartridge"),
	N_("Replace Cartridge"),
	N_("Insert Cartridge"),
	N_("Unknown"),
	NULL,
};

static char *PagesStr = N_("Pages");

static void InitCCInfoDlgWidgets(UIStatusWnd *wnd, int mono, int color, int *status);
static int GetCCInfoData(UIStatusWnd *wnd, int *mono, int *color, int *status);

static void InitCCInfoDlgWidgets2(UIStatusWnd *wnd, int mono, int color);
static int GetCCInfoData2(UIStatusWnd *wnd, int *mono, int *color);

UICCInfoDlg* CreateCCInfoDlg(UIDialog *parent)
{
	UICCInfoDlg *dialog;

	dialog = (UICCInfoDlg *)CreateDialog(sizeof(UICCInfoDlg), parent);

	UI_DIALOG(dialog)->window = create_ConsumablesCounters_dialog();

	return dialog;
}

void ShowCCInfoDlg(UIStatusWnd *wnd)
{
	int mono, color;
	int status[3];

	switch(wnd->nIFVersion){
	case CCPD_IF_VERSION_110:
		if(GetCCInfoData2(wnd, &mono, &color))
			return;
		SigDisable();
		InitCCInfoDlgWidgets2(wnd, mono, color);
		SigEnable();
		break;
	case CCPD_IF_VERSION_100:
	default:
		if(GetCCInfoData(wnd, &mono, &color, status))
			return;
		SigDisable();
		InitCCInfoDlgWidgets(wnd, mono, color, status);
		SigEnable();
		break;
	}

	ShowDialog((UIDialog *)wnd->ccinfo_dlg, NULL);
}

void HideCCInfoDlg(UIStatusWnd *wnd)
{
	HideDialog((UIDialog *)wnd->ccinfo_dlg);
}

void CCInfoDlgOK(UIStatusWnd *wnd)
{
	HideCCInfoDlg(wnd);
}

static char* GetCrtStr(int index)
{
	if(index < CRT_STR_AVAILABLE || index > CRT_STR_UNKNOWN)
		return NULL;

	return _(CartridgeStr[index]);
}

static void InitCCInfoDlgWidgets(UIStatusWnd *wnd, int mono, int color, int *status)
{
	GtkWidget *window = UI_DIALOG(wnd->ccinfo_dlg)->window;
	char ColorCnt[32];
	char MonoCnt[32];
	int i;

	for(i = 0; i < 4; i++){
		int nBit = 1 << i;
		char *str = NULL;

		if(status[2] & nBit)
			str = GetCrtStr(CRT_STR_REPLACE);
		else if(status[1] & nBit)
			str = GetCrtStr(CRT_STR_CHECK);
		else if(status[0] & nBit)
			str = GetCrtStr(CRT_STR_SOON);
		else
			str = GetCrtStr(CRT_STR_AVAILABLE);

		switch(i){
		case 0:
			SetTextToLabel(window, "CCDlg_Black_label", str);
			break;
		case 1:
			SetTextToLabel(window, "CCDlg_Cyan_label", str);
			break;
		case 2:
			SetTextToLabel(window, "CCDlg_Magenta_label", str);
			break;
		case 3:
			SetTextToLabel(window, "CCDlg_Yellow_label", str);
			break;
		}
	}

	memset(MonoCnt, 0, 32);
	snprintf(MonoCnt, 31, "%d %s", mono, _(PagesStr));
	SetTextToLabel(window, "CCDlg_Mono_Cnt_label", MonoCnt);

	memset(ColorCnt, 0, 32);
	snprintf(ColorCnt, 31, "%d %s", color, _(PagesStr));
	SetTextToLabel(window, "CCDlg_Color_Cnt_label", ColorCnt);

}

static int GetCCInfoData(UIStatusWnd *wnd, int *mono, int *color, int *status)
{
	if(cnsktSetReqLong(wnd->pCnskt, DATA_LENGTH_SHORT) < 0)
		goto err;
	if(cnsktSetReqShort(wnd->pCnskt, COUNTER_ID_MONO) < 0)
		goto err;
	if(SendRequest(wnd, CCPD_REQ_COUNTER) < 0)
		goto err;
	if(cnsktGetResData(wnd->pCnskt, mono, READ_TYPE_LONG, -1) < 0)
		goto err;

	if(cnsktSetReqLong(wnd->pCnskt, DATA_LENGTH_SHORT) < 0)
		goto err;
	if(cnsktSetReqShort(wnd->pCnskt, COUNTER_ID_COLOR) < 0)
		goto err;
	if(SendRequest(wnd, CCPD_REQ_COUNTER) < 0)
		goto err;
	if(cnsktGetResData(wnd->pCnskt, color, READ_TYPE_LONG, -1) < 0)
		goto err;

	if(SendRequest(wnd, CCPD_REQ_CRG_STATUS) < 0)
		goto err;

	if(cnsktGetResData(wnd->pCnskt, &status[0], READ_TYPE_LONG, -1) < 0)
		goto err;

	if(cnsktGetResData(wnd->pCnskt, &status[1], READ_TYPE_LONG, -1) < 0)
		goto err;

	if(cnsktGetResData(wnd->pCnskt, &status[2], READ_TYPE_LONG, -1) < 0)
		goto err;

	return 0;
err:
	ShowMsgDlg(wnd, MSG_TYPE_CCINFO_GET_ERR);
	return 1;
}

#define	TONER_K	0x0001
#define	TONER_Y	0x0002
#define	TONER_M	0x0004
#define	TONER_C	0x0008
#define	DRUM_K	0x0010
#define	DRUM_Y	0x0020
#define	DRUM_M	0x0040
#define	DRUM_C	0x0080
#define	WASTE_TONER	0x0100
#define	FUSER	0x0200

static int DataToInfo(UIStatusWnd *wnd, long typebit)
{
	if(wnd->ccinfo_dlg->warning & typebit)
		return CRT_STR_SOON;
	else if(wnd->ccinfo_dlg->out & typebit)
		return CRT_STR_REPLACE;
	else if(wnd->ccinfo_dlg->absent & typebit)
		return CRT_STR_INSERT;
	else
		return CRT_STR_AVAILABLE;
}

static void InitCCInfoDlgWidgets2(UIStatusWnd *wnd, int mono, int color)
{
	GtkWidget *window = UI_DIALOG(wnd->ccinfo_dlg)->window;
	char ColorCnt[32];
	char MonoCnt[32];
	int index;
	char *str = NULL;

	index = DataToInfo(wnd, TONER_K);
	str = GetCrtStr(index);
	SetTextToLabel(window, "CCDlg_Black_label", str);

	str = NULL;
	index = DataToInfo(wnd, TONER_Y);
	str = GetCrtStr(index);
	SetTextToLabel(window, "CCDlg_Yellow_label", str);

	str = NULL;
	index = DataToInfo(wnd, TONER_M);
	str = GetCrtStr(index);
	SetTextToLabel(window, "CCDlg_Magenta_label", str);

	str = NULL;
	index = DataToInfo(wnd, TONER_C);
	str = GetCrtStr(index);
	SetTextToLabel(window, "CCDlg_Cyan_label", str);

	memset(MonoCnt, 0, 32);
	snprintf(MonoCnt, 31, "%d %s", mono, _(PagesStr));
	SetTextToLabel(window, "CCDlg_Mono_Cnt_label", MonoCnt);

	memset(ColorCnt, 0, 32);
	snprintf(ColorCnt, 31, "%d %s", color, _(PagesStr));
	SetTextToLabel(window, "CCDlg_Color_Cnt_label", ColorCnt);
}


static int GetCCInfoData2(UIStatusWnd *wnd, int *mono, int *color)
{
	long dummy = 0;
	long cnt_clr = 0, cnt_bw = 0;
	if(cnsktSetReqLong(wnd->pCnskt, DATA_LENGTH_LONG) < 0)
		goto err;
	if(cnsktSetReqLong(wnd->pCnskt, DREQ_GET_CONSUMABLE) < 0)
		goto err;
	if(SendRequest(wnd, CCPD_DEVICE_REQUEST) < 0)
		goto err;

	if(cnsktGetResData(wnd->pCnskt, &(wnd->ccinfo_dlg->warning), READ_TYPE_LONG, -1) < 0)
		goto err;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	if(cnsktGetResData(wnd->pCnskt, &(wnd->ccinfo_dlg->out), READ_TYPE_LONG, -1) < 0)
		goto err;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	if(cnsktGetResData(wnd->pCnskt, &(wnd->ccinfo_dlg->absent), READ_TYPE_LONG, -1) < 0)
		goto err;


	if(cnsktSetReqLong(wnd->pCnskt, DATA_LENGTH_LONG) < 0)
		goto err;
	if(cnsktSetReqLong(wnd->pCnskt, DREQ_GET_COUNTER) < 0)
		goto err;
	if(SendRequest(wnd, CCPD_DEVICE_REQUEST) < 0)
		goto err;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_bw += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_bw += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_clr += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_clr += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_bw += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_bw += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_clr += dummy;

	dummy = 0;
	if(cnsktGetResData(wnd->pCnskt, &dummy, READ_TYPE_LONG, -1) < 0)
		goto err;
	cnt_clr += dummy;

	*color = cnt_clr;
	*mono = cnt_bw;

	return 0;
err:
	ShowMsgDlg(wnd, MSG_TYPE_CCINFO_GET_ERR);
	return 1;
}






