/*
 *  Status monitor for Canon CAPT Printer.
 *  Copyright (C) 2004-2009 CANON INC.
 *  All Rights Reserved.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "uimain.h"
#include "widgets.h"
#include "interface.h"
#include "ppapdlg.h"
#include "data_process.h"
#include "ppapdata.h"

const char *cas_radio_widget_table[] = {
	"PPAPDlg_Cas1_radiobutton",
	"PPAPDlg_Cas2_radiobutton",
	"PPAPDlg_Cas3_radiobutton",
	"PPAPDlg_Cas4_radiobutton",
	NULL,
};

void UpdatePPAPDlgWidgets(UIStatusWnd *wnd);

static int GetPPAPDataLBP3600(UIStatusWnd *wnd)
{
	char value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->printer_flag = (int)value;

	value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->num_cassette = (int)value;

	value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->size_tray = (int)value;

	value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->size_cas1 = (int)value;

	value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->size_cas2 = (int)value;

	value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->size_cas3 = (int)value;

	value = 0;
	if(cnsktGetResData(wnd->pCnskt, &value, READ_TYPE_BYTE, -1) == 0)
		wnd->ppap_dlg->size_cas4 = (int)value;
	return 0;
}

UIPPAPDlg* CreatePPAPDlg(UIDialog *parent)
{
	UIPPAPDlg *dialog;

	dialog = (UIPPAPDlg *)CreateDialog(sizeof(UIPPAPDlg), parent);

	UI_DIALOG(dialog)->window = create_PPAP_dialog();

	return dialog;
}

void ShowPPAPDlg(UIStatusWnd *wnd)
{
	if(GetPPAPDataLBP3600(wnd))
		return;

	SigDisable();
	UpdatePPAPDlgWidgets(wnd);
	SigEnable();

	ShowDialog((UIDialog *)wnd->ppap_dlg, NULL);
}

void HidePPAPDlg(UIStatusWnd *wnd)
{
	HideDialog((UIDialog *)wnd->ppap_dlg);
	wnd->ppap = FALSE;
}

void PPAPDlgOK(UIStatusWnd *wnd)
{
	GtkWidget *window = UI_DIALOG(wnd->ppap_dlg)->window;
	int i = 0;
	int slot = 0, page = 0, duplex = 0;

	while(cas_radio_widget_table[i] != NULL){
		if(GetToggleButtonActive(window, (char *)cas_radio_widget_table[i])){
			slot = i + 1;
			break;
		}
		i++;
	}

	switch(slot){
	case 0:
		page = wnd->ppap_dlg->size_tray;
		break;
	case 1:
		page = wnd->ppap_dlg->size_cas1;
		break;
	case 2:
		page = wnd->ppap_dlg->size_cas2;
		break;
	case 3:
		page = wnd->ppap_dlg->size_cas3;
		break;
	case 4:
		page = wnd->ppap_dlg->size_cas4;
		break;
	}

	duplex = GetToggleButtonActive(window, "CheckDuplexUnit_checkbutton");

	HidePPAPDlg(wnd);
	ShowMsgDlg(wnd, MSG_TYPE_PRINT_PPAP);
	if(PrintPPAData(wnd->pCnskt->printer, slot, page, duplex) < 0)
		HideMsgDlg(wnd);
}

void PPAPDlgCancel(UIStatusWnd *wnd)
{
	HidePPAPDlg(wnd);
}

void UpdatePPAPDlgWidgets(UIStatusWnd *wnd)
{
	GtkWidget *window = UI_DIALOG(wnd->ppap_dlg)->window;
	int dplx, cas, i = 0, sensi = 0;

	cas = wnd->ppap_dlg->num_cassette;
	while(cas_radio_widget_table[i] != NULL){
		sensi = (i < cas) ? TRUE : FALSE;
		SetWidgetSensitive(window, (char *)cas_radio_widget_table[i], sensi);
		i++;
	}

	dplx = wnd->ppap_dlg->printer_flag;
	sensi = (dplx & PRINTER_FLAGS_SB_DUPLEX) ? TRUE : FALSE;
	SetWidgetSensitive(window, "CheckDuplexUnit_checkbutton", sensi);

}


